OiRA

Help

1. Undirbúningur
3. Greining + Mat
4. Aðgerðaáætlun
5. Skýrsla
6. Staða 0%

# Hlaða niður skýrslunni og prenta út

Við mælum með því að ávallt sé varðveitt útprentuð útgáfa af áhættumatinu (skýrslunni) í fyrirtækinu!

Skýrsla

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Aðgerðaáætlun

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Yfirlit um áhættur

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Yfirlit yfir aðgerðir til úrbóta

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More